Mandate class

Mandate class. This class includes all Mandate entries.

Constructors

Mandate({required int id, required int subscriptionId, required String mandateId, required String state, required String facilitator, required String? callbackUrl, required String link, required String reference, required String createdAt, required String updatedAt})
Mandate.fromMap(Map map)
Mapping from map to Mandate.
factory

Properties

callbackUrl String?
final
createdAt String
final
facilitator String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
final
mandateId String
final
reference String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
final
subscriptionId int
final
updatedAt String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited